# pran-distributions

pran-distributions is a Python library for dealing with distributions.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install pran-distributions

```bash
pip install pran-distributions
```

## Usage

```python

```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License - please read license.txt